@@ -7,7 +7,7 @@ from decimal import Decimal
 # Pip
 from web3 import Web3
 from web3.eth import Eth
-from web3.contract import ContractFunction
+from web3.contract import ContractEvent, ContractFunction
 from eth_account.signers.local import LocalAccount
 
 from web3_wrapped_contract import WrappedContract
@@ -44,6 +44,17 @@ class ERC20(WrappedContract):
         self.__decimals = None
 
 
+    # --------------------------------------------------- Public properties -------------------------------------------------- #
+
+    @property
+    def approval(self) -> ContractEvent:
+        return self.events.Approval()
+
+    @property
+    def transfer(self) -> ContractEvent:
+        return self.events.Transfer()
+
+
     # ---------------------------------------------------- Public methods ---------------------------------------------------- #
 
     # Read (Cachable)
@@ -130,6 +141,10 @@ class ERC20(WrappedContract):
         self,
         spender: str,
         amount: int,
+        gas: Optional[int] = None,
+        gas_price: Optional[int] = None,
+        max_fee_per_gas: Optional[int] = None,
+        max_priority_fee_per_gas: Optional[int] = None,
         account: Optional[LocalAccount] = None
     ) -> str:
         return self.send_transaction(
@@ -137,6 +152,10 @@ class ERC20(WrappedContract):
                 Web3.toChecksumAddress(spender),
                 amount
             ),
+            gas=gas,
+            gas_price=gas_price,
+            max_fee_per_gas=max_fee_per_gas,
+            max_priority_fee_per_gas=max_priority_fee_per_gas,
             account=account
         )
 
@@ -144,6 +163,10 @@ class ERC20(WrappedContract):
         self,
         spender: str,
         subtracted_value: int,
+        gas: Optional[int] = None,
+        gas_price: Optional[int] = None,
+        max_fee_per_gas: Optional[int] = None,
+        max_priority_fee_per_gas: Optional[int] = None,
         account: Optional[LocalAccount] = None
     ) -> str:
         return self.send_transaction(
@@ -151,6 +174,10 @@ class ERC20(WrappedContract):
                 Web3.toChecksumAddress(spender),
                 subtracted_value
             ),
+            gas=gas,
+            gas_price=gas_price,
+            max_fee_per_gas=max_fee_per_gas,
+            max_priority_fee_per_gas=max_priority_fee_per_gas,
             account=account
         )
 
@@ -161,6 +188,10 @@ class ERC20(WrappedContract):
         self,
         spender: str,
         added_value: int,
+        gas: Optional[int] = None,
+        gas_price: Optional[int] = None,
+        max_fee_per_gas: Optional[int] = None,
+        max_priority_fee_per_gas: Optional[int] = None,
         account: Optional[LocalAccount] = None
     ) -> str:
         return self.send_transaction(
@@ -168,6 +199,10 @@ class ERC20(WrappedContract):
                 Web3.toChecksumAddress(spender),
                 added_value
             ),
+            gas=gas,
+            gas_price=gas_price,
+            max_fee_per_gas=max_fee_per_gas,
+            max_priority_fee_per_gas=max_priority_fee_per_gas,
             account=account
         )
 
@@ -178,6 +213,10 @@ class ERC20(WrappedContract):
         self,
         recipient: str,
         amount: int,
+        gas: Optional[int] = None,
+        gas_price: Optional[int] = None,
+        max_fee_per_gas: Optional[int] = None,
+        max_priority_fee_per_gas: Optional[int] = None,
         account: Optional[LocalAccount] = None
     ) -> str:
         return self.send_transaction(
@@ -185,6 +224,10 @@ class ERC20(WrappedContract):
                 recipient,
                 amount
             ),
+            gas=gas,
+            gas_price=gas_price,
+            max_fee_per_gas=max_fee_per_gas,
+            max_priority_fee_per_gas=max_priority_fee_per_gas,
             account=account
         )
 
@@ -193,6 +236,10 @@ class ERC20(WrappedContract):
         sender: str,
         recipient: int,
         amount: int,
+        gas: Optional[int] = None,
+        gas_price: Optional[int] = None,
+        max_fee_per_gas: Optional[int] = None,
+        max_priority_fee_per_gas: Optional[int] = None,
         account: Optional[LocalAccount] = None
     ) -> str:
         return self.send_transaction(
@@ -201,6 +248,10 @@ class ERC20(WrappedContract):
                 Web3.toChecksumAddress(recipient),
                 amount
             ),
+            gas=gas,
+            gas_price=gas_price,
+            max_fee_per_gas=max_fee_per_gas,
+            max_priority_fee_per_gas=max_priority_fee_per_gas,
             account=account
         )
 
@@ -209,10 +260,18 @@ class ERC20(WrappedContract):
 
     def renounce_ownership(
         self,
+        gas: Optional[int] = None,
+        gas_price: Optional[int] = None,
+        max_fee_per_gas: Optional[int] = None,
+        max_priority_fee_per_gas: Optional[int] = None,
         account: Optional[LocalAccount] = None
     ) -> str:
         return self.send_transaction(
             function=self.functions.renounceOwnership(),
+            gas=gas,
+            gas_price=gas_price,
+            max_fee_per_gas=max_fee_per_gas,
+            max_priority_fee_per_gas=max_priority_fee_per_gas,
             account=account
         )
 
@@ -222,12 +281,20 @@ class ERC20(WrappedContract):
     def transfer_ownership(
         self,
         new_owner: str,
+        gas: Optional[int] = None,
+        gas_price: Optional[int] = None,
+        max_fee_per_gas: Optional[int] = None,
+        max_priority_fee_per_gas: Optional[int] = None,
         account: Optional[LocalAccount] = None
     ) -> str:
         return self.send_transaction(
             function=self.functions.transferOwnership(
                 Web3.toChecksumAddress(new_owner)
             ),
+            gas=gas,
+            gas_price=gas_price,
+            max_fee_per_gas=max_fee_per_gas,
+            max_priority_fee_per_gas=max_priority_fee_per_gas,
             account=account
         )
 
